@@ -25,8 +25,12 @@ import java.util.concurrent.ConcurrentMap;
 
 import org.apache.log4j.helpers.NullEnumeration;
 import org.apache.log4j.legacy.core.CategoryUtil;
+import org.apache.log4j.or.ObjectRenderer;
+import org.apache.log4j.or.RendererSupport;
 import org.apache.log4j.spi.LoggerFactory;
 import org.apache.log4j.spi.LoggingEvent;
+import org.apache.logging.log4j.message.MapMessage;
+import org.apache.logging.log4j.message.SimpleMessage;
 import org.apache.logging.log4j.spi.ExtendedLogger;
 import org.apache.logging.log4j.spi.LoggerContext;
 import org.apache.logging.log4j.message.LocalizedMessage;
@@ -50,6 +54,7 @@ public class Category {
 
     private static final boolean isCoreAvailable;
 
+    private final Map<Class<?>, ObjectRenderer> rendererMap;
 
     static {
         boolean available;
@@ -76,6 +81,7 @@ public class Category {
      */
     protected Category(final LoggerContext context, final String name) {
         this.logger = context.getLogger(name);
+        rendererMap = ((RendererSupport) LogManager.getLoggerRepository()).getRendererMap();
     }
 
     /**
@@ -88,6 +94,7 @@ public class Category {
 
     private Category(final org.apache.logging.log4j.Logger logger) {
         this.logger = logger;
+        rendererMap = ((RendererSupport) LogManager.getLoggerRepository()).getRendererMap();
     }
 
     public static Category getInstance(final String name) {
@@ -170,14 +177,17 @@ public class Category {
     }
 
     /**
-     Returns all the currently defined categories in the default
-     hierarchy as an {@link java.util.Enumeration Enumeration}.
-
-     <p>The root category is <em>not</em> included in the returned
-     {@link Enumeration}.
-     @return and Enumeration of the Categories.
-
-     @deprecated Please use {@link LogManager#getCurrentLoggers()} instead.
+     * Returns all the currently defined categories in the default hierarchy as an
+     * {@link java.util.Enumeration Enumeration}.
+     * 
+     * <p>
+     * The root category is <em>not</em> included in the returned
+     * {@link Enumeration}.
+     * </p>
+     * 
+     * @return and Enumeration of the Categories.
+     * 
+     * @deprecated Please use {@link LogManager#getCurrentLoggers()} instead.
      */
     @SuppressWarnings("rawtypes")
     @Deprecated
@@ -215,8 +225,12 @@ public class Category {
         return getEffectiveLevel();
     }
 
+    private String getLevelStr(final Priority priority) {
+        return priority == null ? null : priority.levelStr;
+    }
+
     public void setLevel(final Level level) {
-        setLevel(level.levelStr);
+        setLevel(getLevelStr(level));
     }
 
     public final Level getPriority() {
@@ -224,7 +238,7 @@ public class Category {
     }
 
     public void setPriority(final Priority priority) {
-        setLevel(priority.levelStr);
+        setLevel(getLevelStr(priority));
     }
 
     private void setLevel(final String levelStr) {
@@ -373,13 +387,17 @@ public class Category {
     public static void shutdown() {
     }
 
-
     public void forcedLog(final String fqcn, final Priority level, final Object message, final Throwable t) {
         final org.apache.logging.log4j.Level lvl = org.apache.logging.log4j.Level.toLevel(level.toString());
-        final Message msg = message instanceof Message ? (Message) message : new ObjectMessage(message);
         if (logger instanceof ExtendedLogger) {
-            ((ExtendedLogger) logger).logMessage(fqcn, lvl, null, new ObjectMessage(message), t);
+            @SuppressWarnings("unchecked")
+            Message msg = message instanceof Message ? (Message) message : message instanceof Map ?
+                    new MapMessage((Map) message) : new ObjectMessage(message);
+            ((ExtendedLogger) logger).logMessage(fqcn, lvl, null, msg, t);
         } else {
+            ObjectRenderer renderer = get(message.getClass());
+            final Message msg = message instanceof Message ? (Message) message : renderer != null ?
+                    new RenderedMessage(renderer, message) : new ObjectMessage(message);
             logger.log(lvl, msg, t);
         }
     }
@@ -434,18 +452,18 @@ public class Category {
     }
 
     /**
-     If <code>assertion</code> parameter is {@code false}, then
-     logs <code>msg</code> as an {@link #error(Object) error} statement.
-
-     <p>The <code>assert</code> method has been renamed to
-     <code>assertLog</code> because <code>assert</code> is a language
-     reserved word in JDK 1.4.
-
-     @param assertion The assertion.
-     @param msg The message to print if <code>assertion</code> is
-     false.
-
-     @since 1.2
+     * If <code>assertion</code> parameter is {@code false}, then logs
+     * <code>msg</code> as an {@link #error(Object) error} statement.
+     * 
+     * <p>
+     * The <code>assert</code> method has been renamed to <code>assertLog</code>
+     * because <code>assert</code> is a language reserved word in JDK 1.4.
+     * </p>
+     *
+     * @param assertion The assertion.
+     * @param msg       The message to print if <code>assertion</code> is false.
+     * 
+     * @since 1.2
      */
     public void assertLog(final boolean assertion, final String msg) {
         if (!assertion) {
@@ -469,14 +487,16 @@ public class Category {
 
     public void log(final Priority priority, final Object message, final Throwable t) {
         if (isEnabledFor(priority)) {
-            final Message msg = new ObjectMessage(message);
+            @SuppressWarnings("unchecked")
+            final Message msg = message instanceof Map ? new MapMessage((Map) message) : new ObjectMessage(message);
             forcedLog(FQCN, priority, msg, t);
         }
     }
 
     public void log(final Priority priority, final Object message) {
         if (isEnabledFor(priority)) {
-            final Message msg = new ObjectMessage(message);
+            @SuppressWarnings("unchecked")
+            final Message msg = message instanceof Map ? new MapMessage((Map) message) : new ObjectMessage(message);
             forcedLog(FQCN, priority, msg, null);
         }
     }
@@ -488,13 +508,31 @@ public class Category {
         }
     }
 
-    private void maybeLog(final String fqcn, final org.apache.logging.log4j.Level level,
-            final Object message, final Throwable throwable) {
+    private void maybeLog(
+            final String fqcn,
+            final org.apache.logging.log4j.Level level,
+            final Object message,
+            final Throwable throwable) {
         if (logger.isEnabled(level)) {
-            if (logger instanceof ExtendedLogger) {
-                ((ExtendedLogger) logger).logMessage(fqcn, level, null, new ObjectMessage(message), throwable);
+            final Message msg;
+            if (message instanceof String) {
+                msg = new SimpleMessage((String) message);
+            }
+            // SimpleMessage treats String and CharSequence differently, hence
+            // this else-if block.
+            else if (message instanceof CharSequence) {
+                msg = new SimpleMessage((CharSequence) message);
+            } else if (message instanceof Map) {
+                @SuppressWarnings("unchecked")
+                final Map<String, ?> map = (Map<String, ?>) message;
+                msg = new MapMessage<>(map);
             } else {
-                logger.log(level, message, throwable);
+                msg = new ObjectMessage(message);
+            }
+            if (logger instanceof ExtendedLogger) {
+                ((ExtendedLogger) logger).logMessage(fqcn, level, null, msg, throwable);
+            } else {
+                logger.log(level, msg, throwable);
             }
         }
     }
@@ -531,4 +569,34 @@ public class Category {
         return logger.isEnabled(level);
     }
 
+    private <T> ObjectRenderer get(Class<T> clazz) {
+        ObjectRenderer renderer = null;
+        for (Class<? super T> c = clazz; c != null; c = c.getSuperclass()) {
+            renderer = rendererMap.get(c);
+            if (renderer != null) {
+                return renderer;
+            }
+            renderer = searchInterfaces(c);
+            if (renderer != null) {
+                return renderer;
+            }
+        }
+        return null;
+    }
+
+    ObjectRenderer searchInterfaces(Class<?> c) {
+        ObjectRenderer renderer = rendererMap.get(c);
+        if (renderer != null) {
+            return renderer;
+        }
+        Class<?>[] ia = c.getInterfaces();
+        for (Class<?> clazz : ia) {
+            renderer = searchInterfaces(clazz);
+            if (renderer != null) {
+                return renderer;
+            }
+        }
+        return null;
+    }
+
 }
