@@ -227,7 +227,7 @@ public class StrSubstitutor implements ConfigurationAware {
      * @param valueMap  the map with the variables' values, may be null
      */
     public StrSubstitutor(final Map<String, String> valueMap) {
-        this(new MapLookup(valueMap), DEFAULT_PREFIX, DEFAULT_SUFFIX, DEFAULT_ESCAPE);
+        this(new PropertiesLookup(valueMap), DEFAULT_PREFIX, DEFAULT_SUFFIX, DEFAULT_ESCAPE);
     }
 
     /**
@@ -239,7 +239,7 @@ public class StrSubstitutor implements ConfigurationAware {
      * @throws IllegalArgumentException if the prefix or suffix is null
      */
     public StrSubstitutor(final Map<String, String> valueMap, final String prefix, final String suffix) {
-        this(new MapLookup(valueMap), prefix, suffix, DEFAULT_ESCAPE);
+        this(new PropertiesLookup(valueMap), prefix, suffix, DEFAULT_ESCAPE);
     }
 
     /**
@@ -253,7 +253,7 @@ public class StrSubstitutor implements ConfigurationAware {
      */
     public StrSubstitutor(final Map<String, String> valueMap, final String prefix, final String suffix,
                           final char escape) {
-        this(new MapLookup(valueMap), prefix, suffix, escape);
+        this(new PropertiesLookup(valueMap), prefix, suffix, escape);
     }
 
     /**
@@ -268,7 +268,7 @@ public class StrSubstitutor implements ConfigurationAware {
      */
     public StrSubstitutor(final Map<String, String> valueMap, final String prefix, final String suffix,
                               final char escape, final String valueDelimiter) {
-        this(new MapLookup(valueMap), prefix, suffix, escape, valueDelimiter);
+        this(new PropertiesLookup(valueMap), prefix, suffix, escape, valueDelimiter);
     }
 
     /**
@@ -437,7 +437,7 @@ public class StrSubstitutor implements ConfigurationAware {
      */
     public static String replace(final Object source, final Properties valueProperties) {
         if (valueProperties == null) {
-            return source.toString();
+            return Objects.toString(source, null);
         }
         final Map<String, String> valueMap = new HashMap<>();
         final Enumeration<?> propNames = valueProperties.propertyNames();
