@@ -17,6 +17,8 @@
 */
 package org.apache.logging.slf4j;
 
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Proxy;
 import java.util.Date;
 import java.util.List;
 
@@ -38,9 +40,6 @@ import org.slf4j.MDC;
 import static org.hamcrest.Matchers.*;
 import static org.junit.Assert.*;
 
-/**
- *
- */
 public class LoggerTest {
 
     private static final String CONFIG = "target/test-classes/logback-slf4j.xml";
@@ -125,7 +124,7 @@ public class LoggerTest {
 
     @Test
     public void getLogger_String_MessageFactoryMismatchNull() {
-        final Logger testLogger =  testMessageFactoryMismatch("getLogger_String_MessageFactoryMismatchNull",
+        final Logger testLogger = testMessageFactoryMismatch("getLogger_String_MessageFactoryMismatchNull",
             StringFormatterMessageFactory.INSTANCE, null);
         testLogger.debug("%,d", Integer.MAX_VALUE);
         assertThat(list.strList, hasSize(1));
@@ -137,7 +136,7 @@ public class LoggerTest {
         assertThat(testLogger, is(notNullValue()));
         checkMessageFactory(messageFactory1, testLogger);
         final Logger testLogger2 = LogManager.getLogger(name, messageFactory2);
-        checkMessageFactory(messageFactory1, testLogger2);
+        checkMessageFactory(messageFactory2, testLogger2);
         return testLogger;
     }
 
@@ -163,6 +162,37 @@ public class LoggerTest {
     public void debugWithParms() {
         logger.debug("Hello, {}", "World");
         assertThat(list.strList, hasSize(1));
+        String message = list.strList.get(0);
+        assertEquals("Hello, World", message);
+    }
+
+    @Test
+    public void paramIncludesSubstitutionMarker_locationAware() {
+        logger.info("Hello, {}", "foo {} bar");
+        assertThat(list.strList, hasSize(1));
+        String message = list.strList.get(0);
+        assertEquals("Hello, foo {} bar", message);
+    }
+
+    @Test
+    public void paramIncludesSubstitutionMarker_nonLocationAware() {
+        final org.slf4j.Logger slf4jLogger = CTX.getLogger();
+        Logger nonLocationAwareLogger = new SLF4JLogger(
+                slf4jLogger.getName(),
+                (org.slf4j.Logger) Proxy.newProxyInstance(
+                        getClass().getClassLoader(),
+                        new Class<?>[]{org.slf4j.Logger.class},
+                        (proxy, method, args) -> {
+                            try {
+                                return method.invoke(slf4jLogger, args);
+                            } catch (InvocationTargetException e) {
+                                throw e.getCause();
+                            }
+                        }));
+        nonLocationAwareLogger.info("Hello, {}", "foo {} bar");
+        assertThat(list.strList, hasSize(1));
+        String message = list.strList.get(0);
+        assertEquals("Hello, foo {} bar", message);
     }
 
     @Test
